# Distributed under the OSI-approved BSD 3-Clause License.  See accompanying
# file Copyright.txt or https://cmake.org/licensing for details.

#.rst:
# Findffi
# --------
#
# Find the ffi headers and libraries.
#
# This module reports information about the ffi
# installation in several variables.  General variables::
#
#   ffi_FOUND - true if the ffi headers and libraries were found
#   ffi_INCLUDE_DIRS - the directory containing the ffi headers
#   ffi_LIBRARIES - ffi libraries to be linked
#
# The following cache variables may also be set::
#
#   ffi_INCLUDE_DIR - the directory containing the ffi headers
#   ffi_LIBRARY - the ffi library (if any)
#

# Find include directory
find_path(ffi_INCLUDE_DIR
          NAMES "ffi.h"
          DOC "ffi include directory")
mark_as_advanced(ffi_INCLUDE_DIR)

# Find ffi library
find_library(ffi_LIBRARY "libffi" DOC "ffi libraries")
mark_as_advanced(ffi_LIBRARY)
mark_as_advanced(ffi_DIR)

include(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(ffi
                                  FOUND_VAR ffi_FOUND
                                  REQUIRED_VARS ffi_INCLUDE_DIR
                                  REQUIRED_VARS ffi_LIBRARY
                                  FAIL_MESSAGE "Failed to find ffi")

if(ffi_FOUND)
  set(ffi_INCLUDE_DIRS "${ffi_INCLUDE_DIR}")
  if(ffi_LIBRARY)
    set(ffi_LIBRARIES "${ffi_LIBRARY}")
  else()
    unset(ffi_LIBRARIES)
  endif()
endif()
